"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const slug_1 = tslib_1.__importDefault(require("slug"));
const isString_1 = tslib_1.__importDefault(require("lodash/isString"));
class Edge {
    constructor(fileName, content = "", frontmatter = {}, publicPath = "", destPath = "", excerpt) {
        this._fileName = fileName;
        this._html = content;
        this._frontmatter = frontmatter;
        this._publicPath = publicPath;
        this._destPath = destPath;
        this._excerpt = excerpt;
    }
    get fileName() {
        return this._fileName;
    }
    get html() {
        return this._html;
    }
    get frontmatter() {
        return this._frontmatter;
    }
    get relativePath() {
        return this.getDestinationPath().replace(this._publicPath, "");
    }
    get excerpt() {
        return this._excerpt;
    }
    get slug() {
        return slug_1.default(this.fileName.toLowerCase());
    }
    get query() {
        if (this.frontmatter.hasOwnProperty("query")) {
            const { query } = this.frontmatter;
            if (isString_1.default(query)) {
                return query;
            }
            else {
                throw new Error('"query" must be a string');
            }
        }
        else {
            return "";
        }
    }
    hasQuery() {
        return this.frontmatter.hasOwnProperty("query");
    }
    getDestinationPath() {
        const firstSegment = !this._destPath || this._destPath === "/" ? "" : this._destPath;
        // A user can choose to not use pretty url for a page by setting `pretty_url: false` in the page Front Matter
        if (this.frontmatter.hasOwnProperty("pretty_url") &&
            !this.frontmatter.pretty_url) {
            return `${firstSegment}/${this.fileName}.html`;
        }
        if (this.fileName !== "index") {
            return `${firstSegment}/${this.slug}/index.html`;
        }
        else {
            return `${firstSegment}/index.html`;
        }
    }
    asObject(isActive = false) {
        return {
            html: this.html,
            frontmatter: this.frontmatter,
            relativePath: this.relativePath,
            excerpt: this.excerpt,
            active: isActive
        };
    }
}
exports.Edge = Edge;
